#!/bin/dash
#----------------------------------------------------------------------------#
# Xymon client main script.                                                  #
#                                                                            #
# This invokes the OS-specific script to build a client message, and sends   #
# if off to the Xymon server.                                                #
#                                                                            #
# Copyright (C) 2005-2011 Henrik Storner <henrik@hswn.dk>                    #
#                                                                            #
# This program is released under the GNU General Public License (GPL),       #
# version 2. See the file "COPYING" for details.                             #
#                                                                            #
#----------------------------------------------------------------------------#
#
# $Id: xymonclient.sh 7204 2013-07-23 12:20:59Z storner $

# Must make sure the commands return standard (english) texts.
LANG=C
LC_ALL=C
LC_MESSAGES=C
export LANG LC_ALL LC_MESSAGES

LOCALMODE="no"
if test $# -ge 1; then
	if test "$1" = "--local"; then
		LOCALMODE="yes"
	fi
	shift
fi

if test "$LOCALMODE" = "yes" -a ! -x /usr/libexec/xymon-client/xymond_client; then
	echo "ERROR: Local mode (--local) disabled because /usr/libexec/xymon-client/xymond_client not found; you may need to install a xymon-client-local package" >&2
	LOCALMODE="no"
fi

if test "$XYMONOSSCRIPT" = ""; then
	XYMONOSSCRIPT="xymonclient-`uname -s | tr '[ABCDEFGHIJKLMNOPQRSTUVWXYZ/]' '[abcdefghijklmnopqrstuvwxyz_]'`.sh"
fi

MSGFILE="$XYMONTMP/msg.$MACHINEDOTS.txt"
MSGTMPFILE="$MSGFILE.$$"
LOGFETCHCFG=$XYMONTMP/logfetch.$MACHINEDOTS.cfg
LOGFETCHSTATUS=$XYMONCLIENTLOGS/logfetch.$MACHINEDOTS.status
export LOGFETCHCFG LOGFETCHSTATUS

rm -f $MSGTMPFILE
touch $MSGTMPFILE


CLIENTVERSION="Xymon version 4.3.17-1.fc18"

if test "$LOCALMODE" = "yes"; then
	echo "@@client#1|0|127.0.0.1|$MACHINEDOTS|$SERVEROSTYPE" >> $MSGTMPFILE
fi

if test "$STATUSMODE" = "yes"; then
	echo "status $MACHINE.xymonclient client $SERVEROSTYPE $CONFIGCLASS"  >>  $MSGTMPFILE
else
	echo "client $MACHINE.$SERVEROSTYPE $CONFIGCLASS"  >>  $MSGTMPFILE
fi

/usr/libexec/xymon-client/$XYMONOSSCRIPT >> $MSGTMPFILE
# logfiles
if test -f $LOGFETCHCFG
then
    /usr/libexec/xymon-client/logfetch $LOGFETCHCFG $LOGFETCHSTATUS >>$MSGTMPFILE
fi
# Client version
echo "[clientversion]"  >>$MSGTMPFILE
echo "$CLIENTVERSION"   >> $MSGTMPFILE

# See if there are any individual client sections
if test -d /usr/share/xymon-client/sections; then
	for MODULE in `ls /usr/share/xymon-client/sections/* 2>/dev/null | grep -v -e \.rpm -e \.dpkg`
	do
		if test -x $MODULE -a -f $MODULE
		then
			echo "[`basename $MODULE`]" >>$MSGTMPFILE
			$MODULE >>$MSGTMPFILE
		fi
	done
fi

# See if there are any local add-ons (must do this before checking the clock)
if test -d /usr/local/share/xymon-client -o -d /usr/share/xymon-client/local; then
	for MODULE in /usr/local/share/xymon-client/* /usr/share/xymon-client/local/*
	do
		if test -x $MODULE
		then
			echo "[local:`basename $MODULE`]" >>$MSGTMPFILE
			$MODULE >>$MSGTMPFILE
		fi
	done
fi

# System clock
echo "[clock]"          >> $MSGTMPFILE
/usr/libexec/xymon-client/logfetch --clock >> $MSGTMPFILE

if test "$LOCALMODE" = "yes"; then
	echo "@@" >> $MSGTMPFILE
	/usr/libexec/xymon-client/xymond_client --local --config=/etc/xymon-client/localclient.cfg <$MSGTMPFILE
elif test "$STATUSMODE" = "yes"; then
	# Send to any/all at once, and discard output since there won't be any
	for THISSRV in $XYMSERVERS; do
		$XYMON $THISSRV "@" < $MSGTMPFILE >/dev/null &
	done
	sleep 4
else
	$XYMON $XYMSRV "@" < $MSGTMPFILE >$LOGFETCHCFG.tmp
	if test -f $LOGFETCHCFG.tmp
	then
		if test -s $LOGFETCHCFG.tmp
		then
			mv $LOGFETCHCFG.tmp $LOGFETCHCFG
		else
			rm -f $LOGFETCHCFG.tmp
		fi
	fi
fi

# Save the latest file for debugging.
rm -f $MSGFILE
mv $MSGTMPFILE $MSGFILE

exit 0

